@@ -45,15 +45,13 @@ int main(int argc, char *argv[])
 	int grid_size = 4;
 	int roughness = 100;
 	int fg = 0;
-	int cpuwait = 1; // this is to slow down the bugs ... higher is slower
-
+	int dm = 0;
 
 	/* default world size to phyical screen */
 	world_row = RROW - 5;
 	world_col = RCOL;
 		
 	/* parse cammand line */
-	printf("Parsing command line ...\n");
 	if (argc > 1)
 	{
 		for (temp = 1; temp < argc; temp++)
@@ -109,35 +107,43 @@ int main(int argc, char *argv[])
 	}
 	
 	/* setup some stuff */
-	printf("Malloc world ...\n");
+	printf("In the the beginning there was void ...\n");
+
 	/* make the world */
 	if ((world = (char *)malloc(world_row * world_col)) == NULL)
 	{
 		printf("bad malloc ... no world!!!\n");
 		exit(BM_B6);
 	}
+	printf("So we made a world and it was good ...\n");
 
 	/* seed the random number generator */
-	printf("Seed rand ...\n");
- 	srand ((unsigned) time ( NULL ));
+ 	srand((unsigned)time( NULL ));
+ 	printf("Then we introduced chaos ...\n");
 
 	/* generate the terrain */
-	printf("Making world ...\n");
-	generateterrain (grid_size, roughness);
-
-	/* initalize the keyboard */
-	printf("Init kb ...\n");
-	init_kb();
+	generateterrain(grid_size, roughness);
+	printf("The mountians and waters formed and they were good ...\n");
 
 	/* place food */
-	printf("Placeing food ...\n");
 	for (temp = 0 ; temp < NUM_FOOD ; temp++)
 		placefood();
+	printf("Soon plants started to grow ...\n");
 
 	/* place bugs */
-	printf("Placeing bugs ...\n");
 	start();
-
+	printf("And bugs appeared ...\n");
+	printf("\n");
+	printf("They ate the plants and sometimes each other ...\n");
+	printf("They began to bread and evolve ...\n");
+	
+	/* initalize the keyboard */
+	init_kb();
+	
+	while(!kb_hit());
+	sd = read_kb();
+	sd = '\0';
+	
 	/* clear the screen */
 	printf("%c[2J", 033);
 
@@ -148,39 +154,59 @@ int main(int argc, char *argv[])
 	hg = bugs;
 	old = bugs;
 	hk = bugs;
+	
+	u1mode = 2;
+	u2mode = 3;
 		
 	/* main loop */
 	for (;;)
 	{
-		// first bug in loop better check out some stuff
+		/* first bug in loop better check out some stuff */
 		if (bugs == first)
 		{
 			/* show this frame */
-			display(tmpr, tmpc);
-		
-			// be nice to the processor
-			if (cpuwait)
-				usleep (cpuwait);
+			switch(dm)
+			{
+				case 0: /* world display */
+					display(tmpr, tmpc);
+					break;
+				case 1: /* min */
+					stat(0);
+					break;
+				case 2: /* min */
+					stat(1);
+					break;
+				case 3: /* min */
+					stat(2);
+					break;
+				case 4: /* min */
+					stat(3);
+					break;
+				default:
+					printf("oops .. bad display mode\n");
+					break;
+			}
 
-			// grow food?
+			/* grow food? */
 			fg = ++fg % FOOD_GROW;
-		} // end first bug
+
+		} /* end first bug */
 		
-		// start of gorwth cycle check some other stuff
+		/* start of gorwth cycle check some other stuff */
 		if (fg == 0)
 		{
-			// grow some food
+			/* grow some food */
 			if (bugs == first)
-				growfood ();
+				growfood();
 		
-			// get older
+			/* get older */
 			bugs->age++;
 						
-			// did bug eat lots???
+			/* did bug eat lots??? */
 			if (bugs->food >= SPLIT_LVL)
-				mate ();
+				mate();
 				
-			// keep track of special bugs
+			/* keep track of special bugs */
 			if (bugs->food > hf->food)
 				hf = bugs;
 
@@ -193,51 +219,53 @@ int main(int argc, char *argv[])
 			if (bugs->things[FOOD3] < hk->things[FOOD3])
 				hk = bugs;
 
-			// did bug starve to death ???
+			/* did bug starve to death ??? */
 			if (bugs->food <= 0)
 			{
 				if (sb == bugs)
-				die (bugs);
+					bugs = bugs->next;
+					
+				die(bugs);
 			}	
-		} // end of other stuff
+		} /* end of other stuff */
 			
 		bugs = bugs->next;
 		world[world_col * bugs->ypos + bugs->xpos] = SPC;
 
-		// what is bug doing???
-		switch (look ())
+		/* what is bug doing??? */
+		switch (look())
 		{
-			case WAIT: // do nothing
+			case WAIT: /* do nothing */
 				bugs->food -= WAIT_F;
 				break;
 
-			case RIGHT: // turn left
+			case RIGHT: /* turn left */
 				bugs->food -= TURN_F;
 				bugs->vector = (bugs->vector + 1) % 4;        
 				break;
 
-			case LEFT: // turn right
+			case LEFT: /* turn right */
 				bugs->food -= TURN_F;
 				bugs->vector = (bugs->vector + 3) % 4;
 				break;
 
-			case FORWARD: // move ahead
+			case FORWARD: /* move ahead */
 				bugs->food -= MOVE_F;
 				switch (bugs->vector)
 				{
-					case 0:	// screen up
+					case 0:	/* screen up */
 						bugs->ypos = (--bugs->ypos + world_row) % world_row;
 						break;
 
-					case 1: // screen right
+					case 1: /* screen right */
 						bugs->xpos = (++bugs->xpos) % world_col;
 						break;
 
-					case 2: //screen down
+					case 2: /* screen down */
 						bugs->ypos = (++bugs->ypos) % world_row;
 						break;
 
-					case 3: // screen left
+					case 3: /* screen left */
 						bugs->xpos = (--bugs->xpos + world_col) % world_col;
 						break;                                          
 
@@ -250,7 +278,8 @@ int main(int argc, char *argv[])
 			default:
 				fprintf (stderr, "default in main look returned a bad value\n");
 				break;
-		} // bug done
+		
+		} /* bug done */
 
 		world[world_col * bugs->ypos + bugs->xpos] = bugs->race;
 
@@ -258,7 +287,7 @@ int main(int argc, char *argv[])
 		if (kb_hit())
 			sd = read_kb();
 			
-		/* what are doing? */
+		/* what is user doing? */
 		switch (sd)
 		{
 			case '\0': /* do nothing */
@@ -287,6 +316,18 @@ int main(int argc, char *argv[])
 			case 'x': /* exit */
 				stop(EXIT_OK);
 				break;
+
+			case 'm': /* change display mode */
+				dm = ++dm % 5;
+				break;
+
+			case '-': /* user display mode panel 1 */
+				u1mode = ++u1mode % 7;
+				break;
+
+			case '+': /* user display mode panel 2 */
+				u2mode = ++u2mode % 7;
+				break;
 				
 			default: /* bad user ... */
 				printf("bad key");
