@@ -28,4 +28,7 @@
 /* terrain.c */
 #define BM_GT	11	/* bad malloc elevation map */
 
+/* start.c */
+#define MB_ST	12	/* bad malloc new bug */
+
 #endif /* ERROR_H */
