@@ -35,8 +35,9 @@ void die (struct bug *temp)
 	temp->next->prev = temp->prev;
 
 	if (bugs == bugs->next)
-		stop (ALL_D);
-	free (temp);
+		stop(ALL_D);
+	
+	free(temp);
 
 	return;
 }
@@ -50,75 +51,76 @@ void mate (void)
 	int tmin, tmax;
 
 
-	// where is the mate???
+	/* where is the mate??? */
 	if (bugs->food < SPLIT_LVL)
 		switch (bugs->vector)
 		{
-			case 0:
-				// screen up
-				mate = findbug ((bugs->ypos - 1 + world_row) % world_row, bugs->xpos);
+			case 0:	/* screen up */
+				mate = findbug((bugs->ypos - 1 + world_row) % world_row, bugs->xpos);
 				break;
-			case 1:
-				// screen right
-				mate = findbug (bugs->ypos, (bugs->xpos + 1) % world_col);
+
+			case 1:	/* screen right */
+				mate = findbug(bugs->ypos, (bugs->xpos + 1) % world_col);
 				break;
-			case 2:
-				// screen down
-				mate = findbug ((bugs->ypos + 1) % world_row, bugs->xpos);
+
+			case 2:	/* screen down */
+				mate = findbug((bugs->ypos + 1) % world_row, bugs->xpos);
 				break;
-			case 3: 
-				// screen left
-				mate = findbug (bugs->ypos, (bugs->xpos - 1 + world_col) % world_col);
+
+			case 3: /* screen left */
+				mate = findbug(bugs->ypos, (bugs->xpos - 1 + world_col) % world_col);
 				break;                                          
+
 			default:
-				fprintf (stderr, "default in mate find bugs->vector is bad\n");
+				fprintf(stderr, "default in mate find bugs->vector is bad\n");
 				break;
 		}
 	else
 		mate = bugs;
 	
-	temp = (struct bug *) malloc (sizeof (struct bug));
+	temp = (struct bug *)malloc(sizeof (struct bug));
 	
 	do {
 		temp->ypos = -1;
 		temp->xpos = -1;
 
-		tmin = (bugs->ypos + world_row - getrandom (1, distance)) % world_row;
+		tmin = (bugs->ypos + world_row - getrandom(1, distance)) % world_row;
 		tmax = (bugs->ypos + getrandom(1, distance)) % world_row;
 		while ((temp->ypos < 0) || (temp->ypos > world_row))
-			temp->ypos = tmin < tmax ? getrandom (tmin, tmax) : getrandom (tmax, tmin);
+			temp->ypos = tmin < tmax ? getrandom(tmin, tmax) : getrandom(tmax, tmin);
 
-		tmin = (bugs->xpos + world_col - getrandom (1, distance)) % world_col;
-		tmax = (bugs->xpos + getrandom (1, distance)) % world_col;
+		tmin = (bugs->xpos + world_col - getrandom(1, distance)) % world_col;
+		tmax = (bugs->xpos + getrandom(1, distance)) % world_col;
 		while ((temp->xpos < 0) || (temp->xpos > world_col))
-			temp->xpos = tmin < tmax ? getrandom (tmin, tmax) : getrandom (tmax, tmin);
+			temp->xpos = tmin < tmax ? getrandom(tmin, tmax) : getrandom(tmax, tmin);
 
 		if (++distance > 20)
 		{
 			bugs->food = ((bugs->food * 2) / 3) - MATE_COST;
-			free (temp);
+			free(temp);
 			return;
 		}
+
 	} while (world[world_col * temp->ypos + temp->xpos] != SPC);
 
 	temp->race = bugs->race;
 	temp->gen = bugs->gen + 1;
-	temp->vector = getrandom (0, 3);
+	temp->vector = getrandom(0, 3);
 	temp->age = 0;
 
-	temp->size = bugs->size + getrandom (-D_SIZE, D_SIZE);
+	temp->size = bugs->size + getrandom(-D_SIZE, D_SIZE);
 	if (temp->size < L_SIZE)
 		temp->size = L_SIZE;
 	if (temp->size > H_SIZE)
 		temp->size = H_SIZE;
 
-	temp->attack = bugs->attack + getrandom (-D_SKILL, D_SKILL);
+	temp->attack = bugs->attack + getrandom(-D_SKILL, D_SKILL);
 	if (temp->attack < L_SKILL)
 		temp->attack = L_SKILL;
 	if (temp->attack > H_SKILL)
 		temp->attack = H_SKILL;
 
-	temp->defend = bugs->defend + getrandom (-D_SKILL, D_SKILL);
+	temp->defend = bugs->defend + getrandom(-D_SKILL, D_SKILL);
 	if (temp->defend < L_SKILL)
 		temp->defend = L_SKILL;
 	if (temp->defend > H_SKILL)
@@ -133,7 +135,7 @@ void mate (void)
 			temp->defend = L_SKILL;
 	}
 	 
-	if ((temp->fov = sqrt (temp->size)) > H_FOV)
+	if ((temp->fov = sqrt(temp->size)) > H_FOV)
 		temp->fov = H_FOV;
 
 	temp->food = bugs->food / 3;
@@ -142,10 +144,12 @@ void mate (void)
 	for (loop2 = 0; loop2 < 256; loop2++)
 	{
 		temp->things[loop2] = bugs->things[loop2] * RF;
-		if ((is_bug ((char)loop2)) && (temp->things[loop2] == 0))
-			temp->things[loop2] = getrandom (-ID, ID);
+		if ((is_bug((char)loop2)) && (temp->things[loop2] == 0))
+			temp->things[loop2] = getrandom(-ID, ID);
 	}
-	temp->things[FOOD3] += getrandom (-ID, ID);
+	
+	temp->things[FOOD3] += getrandom(-ID, ID);
+	
 	if (temp->things[FOOD3] > FOOD_VAL)
 		temp->things[FOOD3] = FOOD_VAL;
 		
